---
name: Feature request
about: Suggest an idea for this project
title: ''
labels: enhancement
assignees: ''

---

**Problem Description**
A clear and concise description of what the problem is, e.g. probatus currently does not allow to use this model.

**Desired Outcome**
A clear and concise description of what you want to happen.

**Solution Outline**
If you have an idea how the solution should look like, please describe it.
